@@ -19,7 +19,7 @@
 #'   list of mirrors at \url{https://ctan.org/mirrors}.
 #' @param extra_packages A character vector of extra LaTeX packages to be
 #'   installed.
-#' @references See the TinyTeX documentation (\url{https://yihui.name/tinytex/})
+#' @references See the TinyTeX documentation (\url{https://yihui.org/tinytex/})
 #'   for the default installation directories on different platforms.
 #' @export
 install_tinytex = function(
@@ -70,7 +70,7 @@ install_tinytex = function(
       'TinyTeX was not successfully installed or configured.',
       if (p != '') c(' tlmgr was found at ', p) else {
         c('Your PATH variable is ', Sys.getenv('PATH'))
-      }, '. See https://yihui.name/tinytex/faq/ for more information.'
+      }, '. See https://yihui.org/tinytex/faq/ for more information.'
     )
   }, add = TRUE)
 
@@ -118,7 +118,7 @@ install_tinytex = function(
         Sys.setenv(CTAN_REPO = repository)
         on.exit(Sys.unsetenv('CTAN_REPO'), add = TRUE)
       }
-      download_file('https://yihui.name/gh/tinytex/tools/install-unx.sh')
+      download_file('https://yihui.org/gh/tinytex/tools/install-unx.sh')
       res = system2('sh', c(
         'install-unx.sh', if (not_ctan) c(
           '--no-admin', '--path', shQuote(repository), if (macos && https) 'tlgpg'
@@ -147,9 +147,9 @@ install_tinytex = function(
         if (repository == 'ctan') 'http://mirror.ctan.org/systems/texlive/tlnet' else repository,
         '/install-tl.zip'
       ), mode = 'wb')
-      download_file('https://yihui.name/gh/tinytex/tools/pkgs-custom.txt')
+      download_file('https://yihui.org/gh/tinytex/tools/pkgs-custom.txt')
       pkgs_custom = readLines('pkgs-custom.txt')
-      download_file('https://yihui.name/gh/tinytex/tools/tinytex.profile')
+      download_file('https://yihui.org/gh/tinytex/tools/tinytex.profile')
       x = readLines('tinytex.profile')
       writeLines(gsub('./', './TinyTeX/', x, fixed = TRUE), 'tinytex.profile')
       unzip('install-tl.zip')
@@ -306,7 +306,7 @@ download_file = function(...) {
 
 # LaTeX packages that I use
 install_yihui_pkgs = function() {
-  pkgs = readLines('https://yihui.name/gh/tinytex/tools/pkgs-yihui.txt')
+  pkgs = readLines('https://yihui.org/gh/tinytex/tools/pkgs-yihui.txt')
   tlmgr_install(pkgs)
 }
 
@@ -317,7 +317,7 @@ install_prebuilt = function() {
     download_file('https://ci.appveyor.com/api/projects/yihui/tinytex/artifacts/TinyTeX.zip', installer)
     install_windows_zip(installer)
   } else if (is_linux()) {
-    system('wget -qO- https://yihui.name/gh/tinytex/tools/download-travis-linux.sh | sh')
+    system('wget -qO- https://yihui.org/gh/tinytex/tools/download-travis-linux.sh | sh')
   } else {
     stop('TinyTeX was not prebuilt for this platform.')
   }
