@@ -189,7 +189,12 @@ latexmk_emu = function(
     }
     res = system2_quiet(
       engine, c('-halt-on-error', '-interaction=batchmode', engine_args, shQuote(file)),
-      error = on_error(), logfile = logfile, fail_rerun = getOption('tinytex.verbose', FALSE)
+      error = {
+        if (install_packages) tlmgr_update(
+          run_fmtutil = FALSE, .quiet = TRUE, stdout = FALSE, stderr = FALSE
+        )
+        on_error()
+      }, logfile = logfile, fail_rerun = getOption('tinytex.verbose', FALSE)
     )
     # PNAS you are the worst! Why don't you singal an error in case of missing packages?
     if (res == 0 && !file.exists(filep)) on_error()
@@ -305,7 +310,7 @@ use_file_stdout = function() {
 show_latex_error = function(
   file, logfile = gsub('[.]tex$', '.log', basename(file)), force = FALSE
 ) {
-  e = c('Failed to compile ', file, '. See https://yihui.name/tinytex/r/#debugging for debugging tips.')
+  e = c('Failed to compile ', file, '. See https://yihui.org/tinytex/r/#debugging for debugging tips.')
   if (!file.exists(logfile)) stop(e, call. = FALSE)
   x = readLines(logfile, warn = FALSE)
   b = grep('^\\s*$', x)  # blank lines
@@ -481,6 +486,7 @@ detect_files = function(text) {
   # Package widetext error: Install the flushend package which is a part of sttools
   # Package biblatex Info: ... file 'trad-abbrv.bbx' not found
   # ! Package pdftex.def Error: File `logo-mdpi-eps-converted-to.pdf' not found
+  # ! xdvipdfmx:fatal: pdf_ref_obj(): passed invalid object.
   # ! Package tikz Error: I did not find the tikz library 'hobby'... named tikzlibraryhobby.code.tex
   # support file `supp-pdf.mkii' (supp-pdf.tex) is missing
   r = c(
@@ -492,6 +498,8 @@ detect_files = function(text) {
     # the above are messages about missing fonts; below are typically missing .sty or commands
 
     ".* File `(.+eps-converted-to.pdf)'.*",
+    ".*xdvipdfmx:fatal: pdf_ref_obj.*",
+
     ".*! LaTeX Error: File `([^']+)' not found.*",
     ".* file '?([^' ]+)'? not found.*",
     '.*the language definition file ([^ ]+) .*',
@@ -506,7 +514,7 @@ detect_files = function(text) {
     z = grep(p, x, value = TRUE)
     v = gsub(p, '\\1', z)
     if (length(v) == 0) return(v)
-    if (!(p %in% r[1:5])) return(if (p == r[6]) 'epstopdf' else v)
+    if (!(p %in% r[1:5])) return(if (p %in% r[6:7]) 'epstopdf' else v)
     if (p == r[4]) paste0(v, '.sty') else font_ext(v)
   })))
 }
